@@ -36,6 +36,7 @@
 //! ```
 
 use crate::{License, CURRENT_FORMAT, KNOWN_FORMATS};
+use deb822_lossless::IndentPattern;
 use deb822_lossless::{Deb822, Paragraph};
 use std::path::Path;
 
@@ -116,7 +117,7 @@ const LICENSE_FIELD_ORDER: &[&str] = &["License", "Comment"];
 const FILES_SEPARATOR: &str = " ";
 
 /// A copyright file
-#[derive(Debug)]
+#[derive(Debug, Clone, PartialEq)]
 pub struct Copyright(Deb822);
 
 impl Copyright {
@@ -225,7 +226,12 @@ impl Copyright {
             License::Named(name, text) => format!("{}\n{}", name, text),
             License::Text(text) => text.to_string(),
         };
-        para.set_with_field_order("License", &license_text, FILES_FIELD_ORDER);
+        para.set_with_forced_indent(
+            "License",
+            &license_text,
+            &IndentPattern::Fixed(1),
+            Some(FILES_FIELD_ORDER),
+        );
         FilesParagraph(para)
     }
 
@@ -236,10 +242,16 @@ impl Copyright {
         let mut para = self.0.add_paragraph();
         let license_text = match license {
             License::Name(name) => name.to_string(),
-            License::Named(name, text) => format!("{}\n{}", name, text),
-            License::Text(text) => text.to_string(),
+            License::Named(name, text) => format!("{}\n{}", name, encode_field_text(text)),
+            License::Text(text) => encode_field_text(text),
         };
-        para.set_with_field_order("License", &license_text, LICENSE_FIELD_ORDER);
+        // Force 1-space indentation for License field according to DEP-5 spec
+        para.set_with_indent_pattern(
+            "License",
+            &license_text,
+            Some(&IndentPattern::Fixed(1)),
+            Some(LICENSE_FIELD_ORDER),
+        );
         LicenseParagraph(para)
     }
 
@@ -388,6 +400,7 @@ impl Header {
     }
 
     /// Return the underlying Deb822 paragraph, mutably
+    #[deprecated = "Use as_deb822 instead"]
     pub fn as_mut_deb822(&mut self) -> &mut Paragraph {
         &mut self.0
     }
@@ -469,6 +482,11 @@ impl Header {
 pub struct FilesParagraph(Paragraph);
 
 impl FilesParagraph {
+    /// Return the underlying Deb822 paragraph
+    pub fn as_deb822(&self) -> &Paragraph {
+        &self.0
+    }
+
     /// List of file patterns in the paragraph
     pub fn files(&self) -> Vec<String> {
         self.0
@@ -548,7 +566,7 @@ impl FilesParagraph {
 
     /// License in the paragraph
     pub fn license(&self) -> Option<License> {
-        self.0.get("License").map(|x| {
+        self.0.get_multiline("License").map(|x| {
             x.split_once('\n').map_or_else(
                 || License::Name(x.to_string()),
                 |(name, text)| {
@@ -566,11 +584,13 @@ impl FilesParagraph {
     pub fn set_license(&mut self, license: &License) {
         let text = match license {
             License::Name(name) => name.to_string(),
-            License::Named(name, text) => format!("{}\n{}", name, text),
-            License::Text(text) => text.to_string(),
+            License::Named(name, text) => format!("{}\n{}", name, encode_field_text(text)),
+            License::Text(text) => encode_field_text(text),
         };
+        // Force 1-space indentation for License field according to DEP-5 spec
+        let indent_pattern = deb822_lossless::IndentPattern::Fixed(1);
         self.0
-            .set_with_field_order("License", &text, FILES_FIELD_ORDER);
+            .set_with_forced_indent("License", &text, &indent_pattern, Some(FILES_FIELD_ORDER));
     }
 }
 
@@ -579,7 +599,7 @@ pub struct LicenseParagraph(Paragraph);
 
 impl From<LicenseParagraph> for License {
     fn from(p: LicenseParagraph) -> Self {
-        let x = p.0.get("License").unwrap();
+        let x = p.0.get_multiline("License").unwrap();
         x.split_once('\n').map_or_else(
             || License::Name(x.to_string()),
             |(name, text)| {
@@ -594,6 +614,11 @@ impl From<LicenseParagraph> for License {
 }
 
 impl LicenseParagraph {
+    /// Return the underlying Deb822 paragraph
+    pub fn as_deb822(&self) -> &Paragraph {
+        &self.0
+    }
+
     /// Comment associated with the license
     pub fn comment(&self) -> Option<String> {
         self.0.get("Comment")
@@ -608,20 +633,20 @@ impl LicenseParagraph {
     /// Name of the license
     pub fn name(&self) -> Option<String> {
         self.0
-            .get("License")
+            .get_multiline("License")
             .and_then(|x| x.split_once('\n').map(|(name, _)| name.to_string()))
     }
 
     /// Text of the license
     pub fn text(&self) -> Option<String> {
         self.0
-            .get("License")
+            .get_multiline("License")
             .and_then(|x| x.split_once('\n').map(|(_, text)| decode_field_text(text)))
     }
 
     /// Get the license as a License enum
     pub fn license(&self) -> License {
-        let x = self.0.get("License").unwrap();
+        let x = self.0.get_multiline("License").unwrap();
         x.split_once('\n').map_or_else(
             || License::Name(x.to_string()),
             |(name, text)| {
@@ -642,8 +667,10 @@ impl LicenseParagraph {
             License::Named(name, text) => format!("{}\n{}", name, encode_field_text(text)),
             License::Text(text) => encode_field_text(text),
         };
+        // Force 1-space indentation for License field according to DEP-5 spec
+        let indent_pattern = deb822_lossless::IndentPattern::Fixed(1);
         self.0
-            .set_with_field_order("License", &text, LICENSE_FIELD_ORDER);
+            .set_with_forced_indent("License", &text, &indent_pattern, Some(LICENSE_FIELD_ORDER));
     }
 
     /// Set just the license name (short name on the first line)
@@ -945,7 +972,7 @@ License: GPL-3+
             "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
              Files: *\n\
              Copyright: 2024 Test Author\n\
-             License: MIT\n         Permission is hereby granted...\n"
+             License: MIT\n Permission is hereby granted...\n"
         );
     }
 
@@ -970,7 +997,7 @@ License: GPL-3+
         assert_eq!(
             copyright.to_string(),
             "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\n\
-             License: GPL-3+\n         This is the GPL-3+ license text.\n"
+             License: GPL-3+\n This is the GPL-3+ license text.\n"
         );
     }
 
@@ -1013,7 +1040,7 @@ License: GPL-3+
              Files: debian/*\n\
              Copyright: 2024 Author Two\n\
              License: GPL-3+\n\n\
-             License: GPL-3+\n         Full GPL-3+ text here.\n"
+             License: GPL-3+\n Full GPL-3+ text here.\n"
         );
     }
 
@@ -1437,4 +1464,102 @@ License: MIT
         let retrieved = license_para.text().expect("no text");
         assert_eq!(retrieved, "Line 1\n\nLine 2");
     }
+
+    #[test]
+    fn test_set_license_uses_single_space_indent_for_new_multiline() {
+        // Test that set_license() uses 1-space indentation when converting
+        // a single-line license (no existing indentation) to multi-line
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: Apache-2.0
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let mut license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+
+        // Set new multi-line license text
+        let new_license = crate::License::Named(
+            "Apache-2.0".to_string(),
+            "Licensed under the Apache License, Version 2.0".to_string(),
+        );
+        license_para.set_license(&new_license);
+
+        // Verify the new license uses 1-space indentation
+        let result = copyright.to_string();
+        let expected = "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\nLicense: Apache-2.0\n Licensed under the Apache License, Version 2.0\n";
+        assert_eq!(result, expected);
+    }
+
+    #[test]
+    fn test_header_as_deb822() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Upstream-Name: foo
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let header = copyright.header().unwrap();
+        let para = header.as_deb822();
+        assert_eq!(para.get("Upstream-Name"), Some("foo".to_string()));
+    }
+
+    #[test]
+    fn test_files_paragraph_as_deb822() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+Files: *
+Copyright: 2024 Test
+License: MIT
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let files = copyright.iter_files().next().unwrap();
+        let para = files.as_deb822();
+        assert_eq!(para.get("Files"), Some("*".to_string()));
+    }
+
+    #[test]
+    fn test_license_paragraph_as_deb822() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ License text
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let license = copyright.iter_licenses().next().unwrap();
+        let para = license.as_deb822();
+        assert!(para.get("License").unwrap().starts_with("GPL-3+"));
+    }
+
+    #[test]
+    fn test_set_license_normalizes_unusual_indentation() {
+        // Regression test: set_license() should NOT preserve unusual indentation
+        // from the original paragraph, it should always use 1-space indentation
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: Apache-2.0
+                                 Apache License
+                           Version 2.0, January 2004
+                        http://www.apache.org/licenses/
+ .
+   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let mut license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+
+        // Set new license text with normal formatting (no unusual indentation)
+        let new_text = "Licensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0";
+        let new_license = crate::License::Named("Apache-2.0".to_string(), new_text.to_string());
+        license_para.set_license(&new_license);
+
+        // Verify the output uses 1-space indentation, NOT the 33-space from the original
+        let result = copyright.to_string();
+
+        // The bug is now fixed - output uses 1-space indentation regardless of the original formatting
+        let expected = "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\nLicense: Apache-2.0\n Licensed under the Apache License, Version 2.0 (the \"License\");\n you may not use this file except in compliance with the License.\n You may obtain a copy of the License at\n .\n http://www.apache.org/licenses/LICENSE-2.0\n";
+
+        assert_eq!(result, expected);
+    }
 }
